@@ -19,9 +19,7 @@ app.layout = html.Div(
 )
 
 
-@app.callback(
-    Output("graph", "figure"), Input("selection", "value")
-)
+@app.callback(Output("graph", "figure"), Input("selection", "value"))
 def display_animated_graph(selection):
     animations = {
         "GDP - Scatter": px.scatter(
@@ -48,4 +46,4 @@ def display_animated_graph(selection):
             range_y=[0, 4000000000],
         ),
     }
-    return animations[selection]
\ No newline at end of file
+    return animations[selection]
