@@ -4,7 +4,9 @@ import streamlit as st
 import pandas as pd
 import numpy as np
 
-st.write("Streamlit supports a wide range of data visualizations, including [Plotly, Altair, and Bokeh charts](https://docs.streamlit.io/develop/api-reference/charts). 📊 And with over 20 input widgets, you can easily make your data interactive!")
+st.write(
+    "Streamlit supports a wide range of data visualizations, including [Plotly, Altair, and Bokeh charts](https://docs.streamlit.io/develop/api-reference/charts). 📊 And with over 20 input widgets, you can easily make your data interactive!"
+)
 
 all_users = ["Alice", "Bob", "Charly"]
 with st.container(border=True):
@@ -18,4 +20,4 @@ if rolling_average:
 
 tab1, tab2 = st.tabs(["Chart", "Dataframe"])
 tab1.line_chart(data, height=250)
-tab2.dataframe(data, height=250, width=True)
\ No newline at end of file
+tab2.dataframe(data, height=250, width=True)
