@@ -5,12 +5,10 @@ except ImportError:
     # in editable mode with pip. It is highly recommended to install
     # the package from a stable release or in editable mode: https://pip.pypa.io/en/stable/topics/local-project-installs/#editable-installs
     import warnings
+
     warnings.warn("Importing 'jupyterpack' outside a proper installation.")
     __version__ = "dev"
 
 
 def _jupyter_labextension_paths():
-    return [{
-        "src": "labextension",
-        "dest": "jupyterpack"
-    }]
+    return [{"src": "labextension", "dest": "jupyterpack"}]
